==> dklibs-1.23.1.tbz: include/dklogc.h <==
/*
Copyright (c) 2000-2008, Dirk Krause
All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted provided
that the following conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.
* Redistributions in binary form must reproduce the above 
  opyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials
  provided with the distribution.
* Neither the name of the Dirk Krause nor the names of
  its contributors may be used to endorse or promote
  products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
*/

/**	@file dklogc.h
	Log priorities.
	This file defines constants to choose a priority for log messages.
*/

#ifndef DK_LOGC_INC
#define DK_LOGC_INC 1

/** This message priority never occurs. */
#define DK_LOG_LEVEL_NONE		0

/** Panic message. */
#define DK_LOG_LEVEL_PANIC		1

/** Fatal error message. */
#define DK_LOG_LEVEL_FATAL		2

/** Error message. */
#define DK_LOG_LEVEL_ERROR		3

/** Warning message. */
#define DK_LOG_LEVEL_WARNING		4

/** Informational message. */
#define DK_LOG_LEVEL_INFO		5

/** Progress message. */
#define DK_LOG_LEVEL_PROGRESS		6

/** Debug message. */
#define DK_LOG_LEVEL_DEBUG		7

/** Message can be ignored. */
#define DK_LOG_LEVEL_IGNORE		8

#endif

==> dklibs-1.26.0.tbz: include/dklogc.h <==
/*
Copyright (c) 2000-2008, Dirk Krause
All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted provided
that the following conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.
* Redistributions in binary form must reproduce the above 
  opyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials
  provided with the distribution.
* Neither the name of the Dirk Krause nor the names of
  contributors may be used to endorse or promote
  products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
*/

/**	@file dklogc.h
	Log priorities.
	This file defines constants to choose a priority for log messages.
*/

#ifndef DK_LOGC_INC
#define DK_LOGC_INC 1

/** This message priority never occurs. */
#define DK_LOG_LEVEL_NONE		0

/** Panic message. */
#define DK_LOG_LEVEL_PANIC		1

/** Fatal error message. */
#define DK_LOG_LEVEL_FATAL		2

/** Error message. */
#define DK_LOG_LEVEL_ERROR		3

/** Warning message. */
#define DK_LOG_LEVEL_WARNING		4

/** Informational message. */
#define DK_LOG_LEVEL_INFO		5

/** Progress message. */
#define DK_LOG_LEVEL_PROGRESS		6

/** Debug message. */
#define DK_LOG_LEVEL_DEBUG		7

/** Message can be ignored. */
#define DK_LOG_LEVEL_IGNORE		8

#endif
